jsTree v.1.0 - Demo

# jsTree v.1.0

# DEMO

## Creating a tree, binding events, using the instance

Here is how you create an instance, bind an event and then get the instance.

- Root node 1
  - Child node 1
  - Child node 2
- Root node 2

## Doing something when the tree is loaded

You can use a few events to do that.

- Root node 1
  - Child node 1
  - Child node 2
- Root node 2

## Doing something when a node is clicked

- Root node 1
  - Child node 1
  - Child node 2
- Root node 2

## Using CSS to make nodes wrap

- Root node 1
  - Child node 1 with a long text which would normally just cause a scrollbar, but with this line of CSS it will actually wrap, this is not really throughly tested but it works
  - Child node 2
- Root node 2

## Using CSS to make the nodes bigger

- Root node 1
  - Child node 1 with a long text which would normally just cause a scrollbar, but with this line of CSS it will actually wrap, this is not really throughly tested but it works
  - Child node 2
- Root node 2

## PHP & mySQL demo + event order

Here is a PHP & mySQL enabled demo. You can use the classes/DB structure included, but those are not thoroughly tested and not officially a part of jstree. In the log window you can also see all function calls as they happen on the instance.